==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/postfinanceag_twint.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	postfinanceag_visa.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. CH,AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_CURRENCY_DESC' => 'Währung, welche für Kreditkartentransaktionen verwendet wird',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_CURRENCY_TITLE' => 'Währung',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ERROR' => 'Die Zahlung wurde von der Postfinance abgelehnt!',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_STATUS_DESC' => 'Möchten Sie Zahlungen per Postfinance Twint akzeptieren?',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_STATUS_TITLE' => 'Postfinance Twint Modul aktivieren',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_DESCRIPTION' => 'Postfinance Twint<br />Information: <a href="http://www.postfinance.ch/pf/content/de/seg/biz/product/eserv/epay/seller/offer.html" target="_blank">www.postfinance.ch</a><br />Support: <a href="http://www.swisswebxperts.ch/postfinance.php" target="_blank">www.swisswebXperts.ch</a>',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_ERROR' => 'Twint - Transaktionsfehler',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_INFO' => '',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_TITLE' => 'Twint',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ZONE_TITLE' => 'Zahlungszone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/postfinanceag_twint.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	postfinanceag_visa.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. CH,AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_CURRENCY_DESC' => 'Währung, welche für Kreditkartentransaktionen verwendet wird',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_CURRENCY_TITLE' => 'Währung',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ERROR' => 'Die Zahlung wurde von der Postfinance abgelehnt!',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_STATUS_DESC' => 'Möchtest du Zahlungen per Postfinance Twint akzeptieren?',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_STATUS_TITLE' => 'Postfinance Twint Modul aktivieren',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_DESCRIPTION' => 'Postfinance Twint<br />Information: <a href="http://www.postfinance.ch/pf/content/de/seg/biz/product/eserv/epay/seller/offer.html" target="_blank">www.postfinance.ch</a><br />Support: <a href="http://www.swisswebxperts.ch/postfinance.php" target="_blank">www.swisswebXperts.ch</a>',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_ERROR' => 'Twint - Transaktionsfehler',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_INFO' => '',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_TEXT_TITLE' => 'Twint',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_POSTFINANCEAG_TWINT_ZONE_TITLE' => 'Zahlungszone'
);
